==> haskell-monad-par-extras-0.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
key: monad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
license: BSD3
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
author: Ryan Newton, Simon Marlow
exposed: True
exposed-modules:
    Control.Monad.Par.Combinator Control.Monad.Par.AList
    Control.Monad.Par.State Control.Monad.Par.RNG
hidden-modules: Control.Monad.Par.Pedigree
abi: d7b4abe0ba7f508cecf7e6dae40e011c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-extras-0.3.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
depends:
    abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0 base-4.9.0.0
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi deepseq-1.4.2.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM random-1.1-54KmMHXjttlERYcr1mvsAe
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-6pPrxnfRuo2HoicwqZ1Gcw
key: monad-par-extras-0.3.3-6pPrxnfRuo2HoicwqZ1Gcw
license: BSD3
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
author: Ryan Newton, Simon Marlow
exposed: True
exposed-modules:
    Control.Monad.Par.Combinator Control.Monad.Par.AList
    Control.Monad.Par.State Control.Monad.Par.RNG
hidden-modules: Control.Monad.Par.Pedigree
abi: cdf8d9fd5862ec3851b38453b06f14c3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-6pPrxnfRuo2HoicwqZ1Gcw
depends:
    abstract-par-0.3.3-FIXQeoD8JqS8Il9xkWRf07 base-4.9.1.0
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw deepseq-1.4.2.0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 random-1.1-9tceXaeYIMZ4JrKq20Egog
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
